"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
class Script {
  constructor(src) {
    this.state = 'PENDING';
    this.listeners = [];
    const script = document.createElement('script');
    script.src = src;
    script.async = true;
    const load = () => {
      this.state = 'LOADED';
      script.removeEventListener('load', load);
      this.emitState();
    };
    const error = () => {
      this.state = 'ERROR';
      script.removeEventListener('error', error);
      this.emitState();
    };
    script.addEventListener('load', load);
    script.addEventListener('error', error);
    document.body.appendChild(script);
  }
  onStateChange(cb) {
    this.listeners.push(cb);
    return () => {
      this.listeners = this.listeners.filter(fn => fn !== cb);
    };
  }
  emitState() {
    var _iterator = _createForOfIteratorHelper(this.listeners),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        const cb = _step.value;
        cb(this.state);
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
}
const scripts = new Map();

/**
 * Hook for loading external script
 * @param {string} src - The URL of the script
 * @param {boolean} [doNotLoad=false] - If set to true the script will not be loaded
 *  This can be handy because hooks can not be called conditionally by the consumer
 */
function useScript(src, doNotLoad = false) {
  // Keeping track of script loaded and error state
  const _useState = (0, _react.useState)({
      loaded: false,
      error: false
    }),
    _useState2 = _slicedToArray(_useState, 2),
    state = _useState2[0],
    setState = _useState2[1];
  (0, _react.useEffect)(() => {
    // If doNotLoad we return early so the script will not be loaded
    if (doNotLoad) {
      setState({
        loaded: true,
        error: false
      });
      return;
    }

    // If scripts already includes src it means that the script was already
    // loaded by another instance of the hook, so no need to load again
    const script = scripts.get(src) || scripts.set(src, new Script(src)).get(src);
    if (script.state === 'LOADED') {
      setState({
        loaded: true,
        error: false
      });
      return;
    }
    return script.onStateChange(state => {
      if (state === 'ERROR') {
        scripts.delete(src);
        setState({
          loaded: true,
          error: true
        });
      } else {
        setState({
          loaded: true,
          error: false
        });
      }
    });
  }, [src, doNotLoad]);
  return [state.loaded, state.error];
}
var _default = useScript;
exports.default = _default;